# Copyright 2020 The Pigweed Authors
#
# Licensed under the Apache License, Version 2.0 (the "License"); you may not
# use this file except in compliance with the License. You may obtain a copy of
# the License at
#
#     https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
# License for the specific language governing permissions and limitations under
# the License.
"""Package for calling Pigweed RPCs from Python."""

# TODO(667): Remove this pkgutil snippet
from pkgutil import extend_path

__path__ = extend_path(__path__, __name__)  # type: ignore

from pw_rpc.client import Client
from pw_rpc.descriptors import Channel, ChannelManipulator
